@@ -210,7 +210,7 @@ class Crp:
 
         df_matrix = grp.agg(grp_dict).rename(columns={'id':'num_orders','totalprice':'TotalSpent'})
 
-        df_matrix = self.getRecency(last_orders,dateFlag_sep)
+        df_matrix = self.getRecency(df_matrix,dateFlag_sep)
 
         df_matrix = self.getLastOrderValue(df_matrix,train_df)
 
@@ -274,10 +274,10 @@ class Crp:
         df = self.getFeaturesMatrix(train_data,original_dataset,lag,items_dataset)
         
         # Merge feature sets
-        data = self.getMergedDF(df,'customerid')
+        # data = self.getMergedDF(df,'customerid')
         #Merge with target value 
         
-        finalDF = pd.merge(data,target_value,on='customerid')
+        finalDF = pd.merge(df,target_value,on='customerid')
         
         # finalDf = finalDF.rename(columns = {'num_orders':'Num_orders','totalprice':'Total_spent'})
         
